unit Daoclass;
{ ******************************************************************
  * DAO Server, Version 1.0.0, October 1996                        *
  * Written by Hong-Shuo Li, All rights reserved                   *
  *----------------------------------------------------------------*
  * This unit provides a way to access the Microsoft Data Access   *
  * Object Library version 2.50 (DAO 2.50) for the 16 bit windows  *
  * applications through an out-process (local) OLE automation     *
  * server:       DAOSrver.EXE                                     *
  *----------------------------------------------------------------*
  * Contact: Dr Hong-Shuo Li                                       *
  *          Unit 4, 165 Chapel Road                               *
  *          Bankstown, NSW 2200                                   *
  *          Australia                                             *
  *          Telephone/Fax: (+61 2) 9707 4791                      *
  *          e-mail: hsli@newt.phys.unsw.edu.au                    *
  ****************************************************************** }

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Oleauto, StdCtrls;


type


  VariantArg =Variant;
  TTestForm = class(TForm)
    OleAutoClient1: TOleAutoClient;
    Button1: TButton;
    Edit1: TEdit;
    Edit2: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Edit3: TEdit;
    Label5: TLabel;
    GroupBox1: TGroupBox;
    Label3: TLabel;
    Label4: TLabel;
    Label6: TLabel;
    procedure Button1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

type

  TDAODatabase = class(TOleObject)
  end;

  TDAODBEngine=class(TOleObject)
  private
    function GetIntegerProp(const propName:string):Integer;
    procedure SetIntegerProp(const propName:string;var newValue:Integer);
    function GetBooleanProp(const propName:string) : Boolean;
    procedure SetBooleanProp(const propName:string; const newValue: Boolean);
    function GetStringProp(const propName:String):String;
    function GetLoginTimeout:integer;
    procedure SetLoginTimeout(const newValue:integer);
    function GetVersion : String;
  public
    function CreateDatabase(const Name,Connect:string;Option: Variant):TDAODatabase;
    property LoginTimeout : integer read getLoginTimeout write SetLoginTimeout;
    property Version : String read getVersion;
  end;

  TDAOSession=class(TOleObject)
  private
    FDBEngine:TDAODBEngine;
    function getDBEngine:TDAODBEngine;
  public
    constructor CreateOleObject; 
    destructor Release; override;
    property DBEngine: TDAODBEngine read getDBEngine;
  end;


var
  TestForm:TTestForm;
  mySession:TDAOSession;
  myDB:TDAODBEngine;

implementation

{$R *.DFM}

procedure TTestForm.FormCreate(Sender: TObject);
begin
  mySession:=TDAOSession.CreateOleObject;
  myDB:=mySession.DBEngine;
end;

procedure TTestForm.Button1Click(Sender: TObject);
var i:integer;
begin
  edit1.text:=myDB.Version;
  edit2.text:=IntToStr(myDB.LoginTimeout);
  i:=2*myDB.LoginTimeout;
  myDB.LoginTimeout:=i;
  edit3.text:=IntToStr(myDB.LoginTimeout);
end;

{------ Initiate DAO.DBEngine -------}

constructor TDAOSession.CreateOleObject;
begin
  CreateObject('DAOServer.Session');
end;

destructor TDAOSession.Release;
begin
  { Override destructor to free up the private FDBEngine
    sub-object if it has been created. }
  if Assigned(FDBEngine) then
    FDBEngine.Release;
  inherited Release;
end;

function TDAOSession.GetDBEngine:TDAODBEngine;
var
  pIntDBEngine : PInterface;
begin
  if Assigned(FDBEngine) then
    Result := FDBEngine
  else
  begin
    GetOleProperty('DBEngine', 'pInterface', pIntDBEngine);
    if Assigned(pIntDBEngine) then
    begin
      FDBEngine := TDAODBEngine.ConnectInterface(pIntDBEngine);
      Result := FDBEngine
    end
    else
      Result := nil;
  end;
end;

{--------- DAO.DBEngine Properties -----------------}

{ (a) private functions/procedures }

function TDAODBEngine.GetStringProp(const propName:string):String;
var
  pszVersion : PChar;
begin
    pszVersion:=StrAlloc(256);
    GetOleProperty(propName, 'PChar', pszVersion);
    Result:=StrPas(pszVersion);
    StrDispose(pszVersion);
end;

function TDAODBEngine.GetIntegerProp(const propName:string):Integer;
begin
    GetOleProperty(propName, 'integer', Result);
end;

procedure TDAODBEngine.SetIntegerProp(const propName:string;var newValue:Integer);
begin
    SetOleProperty(propName, 'integer', newValue);
end;

function TDAODBEngine.GetBooleanProp(const propName:string) : Boolean;
begin
  Result := Boolean(GetIntegerProp(propName));
end;

procedure TDAODBEngine.SetBooleanProp(const propName:string; const newValue: Boolean);
var
  intvis : Integer;
begin
  intvis := Integer(NewValue);
  SetIntegerProp(propName, intvis);
end;

{ (b) private functions/procedures }

{ (c) published properties/methods }

function TDAODBEngine.CreateDatabase(const Name,Connect:string;Option: Variant):TDAODatabase;
var myDatabase:TDAODatabase;
begin

end;

function TDAODBEngine.getVersion:String;
begin
    Result:=GetStringProp('Version');
end;

function TDAODBEngine.getLoginTimeout:Integer;
var
  intvis : integer;
begin
    GetOleProperty('LoginTimeout', 'integer', intvis);
    Result:=intvis;
end;

procedure TDAODBEngine.SetLoginTimeout(const newValue:Integer);
var
  intvis : integer;
begin
    intvis:=newValue;
    SetOleProperty('LoginTimeout', 'integer', intvis);
end;

end.
